# context processors for loco-directory
# see: http://docs.djangoproject.com/en/dev/ref/settings/#setting-TEMPLATE_CONTEXT_PROCESSORS
# to use this processor, add "common.context_processors.loco_version" to your variable TEMPLATE_CONTEXT_PROCESSORS in your settings file

from django.conf import settings

def loco_version(request):
    """
    add the loco version to template context processor. 
    """
    
    version = getattr(settings, 'VERSION_STRING', 'unknown')
    return {'loco_version': version}

def google_api_key(request):
    """
    Return the Google API Key or "" if none is defined.
    """

    google_api_key = getattr(settings, 'GOOGLE_API_KEY', '')
    return {'google_api_key': google_api_key}

def flickr_api_key(request):
    """
    Return the Flickr API Key or "" if none is defined.
    """
    
    flickr_api_key = getattr(settings, 'FLICKR_API_KEY', '')
    return {'flickr_api_key': flickr_api_key}
    
def pixie_api_key(request):
    """
    Return the Pix.ie API Key or "" if none is defined.
    """
    
    pixie_api_key = getattr(settings, 'PIXIE_API_KEY', '')
    return {'pixie_api_key': pixie_api_key}

def login_redirect(request):
    return {'login_next': request.get_full_path()}

def url_base(request):
    url = request.get_full_path().split('/')
    return {'url_base': url[1]} 
    
def site_search(request):
    from common.forms import SiteSearchForm
    search_form = SiteSearchForm(data=request.GET)
    return {'search_form': search_form}
