# -*- coding: utf-8 -*-

from django import forms
from django.utils.translation import ugettext_lazy as _

from models import Team, Contacts
from userprofiles.models import UserProfile
from common.forms import RenderableMixin

class UpdateTeamForm(forms.ModelForm, RenderableMixin):
    class Meta:
        model = Team
        exclude = ('approved_date', 'approved', 'expires_date', 'name', 'lp_name', 'admins', 'owner', 'active', 'override_name')

    class Media:
        css = {'all': (
                       '/media/css/colortip-1.0-jquery.css', 
                       )}
        js = (
              '/media/js/colortip-1.0-jquery.js',
              )
              
    def __init__(self, *args, **kwargs):
        super(UpdateTeamForm, self).__init__(*args, **kwargs)
        user_list = self.grouped_user_list()
        self.fields['owner_profile'].choices = user_list
        self.fields['admin_profiles'].choices = user_list
        self.fields['contact_profiles'].choices = user_list
        
    def grouped_user_list(self):
        other_members, team_members = [], []
        for profile in UserProfile.objects.filter(user__groups__name__exact=self.instance.lp_name):
            team_members.append((profile.id, str(profile)))
        for profile in UserProfile.objects.all().exclude(user__groups__name__exact=self.instance.lp_name):
            other_members.append((profile.id, str(profile)))

        return [(_('Team members'), team_members),
                (_('Other users'), other_members)]


class LoCoCouncilForm(UpdateTeamForm, RenderableMixin):
    class Meta(UpdateTeamForm.Meta):
        model = Team
        exclude = ('approved', 'expires_date', 'name', 'lp_name', 'admins', 'owner', 'active')
