from django.test import TestCase

from teams.models import *
from common import launchpad

from django.core.urlresolvers import reverse


class ACLChecksTestCase(TestCase):
# to create this, run: 
#   mkdir teams/fixtures
#   ./manage.py dumpdata --format xml teams > teams/fixtures/test_data.xml
    fixtures = ["test_data.xml"]
    
    def testAdminIsATeamChecks(self):
        """Test if check for a more complicated LoCo Team setup works
        """
        teams = Team.objects.all()
        chile = teams.filter(lp_name="ubuntu-cl")[0]
        self.assertEquals(launchpad.is_admin_or_owner("pvillavi", chile), True)

        venezuela = teams.filter(lp_name="ubuntu-ve")[0]
        self.assertEquals(launchpad.is_admin_or_owner("effie-jayx", venezuela), True)
        self.assertEquals(launchpad.is_admin_or_owner("jorge", venezuela), False)

class EditTeamTestCase(TestCase):
    """
    test if team update works correct
    """
    def test_anonymous_user(self):
        """
        test the team update as anonymous user (not logged in)
        """
        #try to access team-update page as not logged in user
        response = self.client.get(reverse( 'team-edit', args=['ubuntu-de-locoteam'] ), follow=True)
        self.assertRedirects(response, '/openid/login?next=/teams/ubuntu-de-locoteam/edit', status_code=302, target_status_code=200)
        #try to update team as not logged in user
        response = self.client.post(reverse('team-edit', args=['ubuntu-de-locoteam']), {'Country':'Germany', 'forum_url':'http://ubuntuusers.de',  })
        self.assertRedirects(response, '/openid/login?next=/teams/ubuntu-de-locoteam/edit', status_code=302, target_status_code=200)
    
    def test_user_with_no_rights(self):
        """
        test the team update with a user which has no rights
        """
        pass
        #FIXME How to use a user with no right with openid?
    
    def test_user_loco_council(self):
        """
        test the team update with a user which is a member of loco council
        """
        pass
        #FIXME How to use a user with this rights with openid?

    def test_user_admin_or_owner(self):
        """
        test the team update with a user which is owner or admin
        """
        pass
        #FIXME How to use a user with this rights with openid?

class DisplayNameTestCase(TestCase):

    def setUp(self):
        self.team = Team.objects.create(name='Test Team', lp_name='test-team')

    def test_override_name(self):
        # check without override_name
        self.assertEquals(self.team.display_name, 'Test Team')
        
        # check wih override_name
        self.team.override_name = 'Override Name'
        self.team.save()
        self.assertEquals(self.team.display_name, 'Override Name')
        
    def test_display_name_in_list(self):
        self.team.override_name = 'Override Name'
        self.team.save()

        response = self.client.get('/teams/')
        self.assertEquals(response.status_code, 200)
        self.assertContains(response, 'Override Name')

    def test_details_page(self):
        'Make sure the proper name is display on the team details page'
        self.team.override_name = 'Override Name'
        self.team.save()

        response = self.client.get('/teams/test-team/')
        self.assertEquals(response.status_code, 200)
        self.assertContains(response, 'Override Name', 0) # No instances of override_name
        self.assertContains(response, 'Test Team', 3) # One instance of the team name
